@@ -62,13 +62,13 @@ class DatatableRow(NamedTuple):
     coord_north: float
     name: str
     source: str
-    identifier1: str
-    identifier2: str
+    primary_identifier: str
+    count_of_identifiers: int
     primary_tag_subject: str
     primary_tag_temporal: str
     secondary_tag_subject: str
     secondary_tag_temporal: str
-    tag_count: int
+    count_of_period_tags: int
 
 
 @dataclass
@@ -84,22 +84,30 @@ class ParsedLoaction:
 
     def as_datatable_rows(self) -> Generator[DatatableRow, None, None]:
         n_tags = len(self.tags)
-        assert n_tags >= 1, "Must include at least 1 tag"
-        assert len(self.identifiers) == 2, "Expect exactly 2 identifiers per record"
+        n_identifiers = len(self.identifiers)
+        # assert n_tags >= 1, f"\n=> At {self}:\n==> Must include at least 1 temporal tag, got {n_tags}"
+        assert (
+            n_identifiers >= 1
+        ), f"\n=> At {self}:\n==> Expect at least 1 identifier tag, got {n_identifiers}"
         for coord in self.coords:
             coord_e, coord_n = coord.split(",")
+            primary_tag = (
+                self.tags or [SubjectPeriod(MISSING_TAG_TEXT, MISSING_TAG_TEXT)]
+            )[
+                0
+            ]  # in case of 0 tags
             yield DatatableRow(
                 coord_east=float(coord_e),
                 coord_north=float(coord_n),
                 name=self.name,
                 source=self.source,
-                identifier1=self.identifiers[0],
-                identifier2=self.identifiers[1],
-                primary_tag_subject=self.tags[0].subject,
-                primary_tag_temporal=self.tags[0].temporal,
+                primary_identifier=self.identifiers[-1],
+                count_of_identifiers=n_identifiers,
+                primary_tag_subject=primary_tag.subject,
+                primary_tag_temporal=primary_tag.temporal,
                 secondary_tag_subject="" if n_tags < 2 else self.tags[1].subject,
                 secondary_tag_temporal="" if n_tags < 2 else self.tags[1].temporal,
-                tag_count=n_tags,
+                count_of_period_tags=n_tags,
             )
 
 
